
struct conf _far * _far SgetScon(void);
void _far Ssetgate(u_long);
void _far Ssetname(u_long);
u_long _far Sgetname(void);
u_char _far * _far Sgetdomain(void);
u_long _far Sgetbroadcast(void);
void _far Sgetether(u_char _far *);
int _far Snetinit(void);
void _far Snetshut(void);
int _far Socket(u_char, struct sockaddr _far *, u_int, struct port _far *);
int _far SoBind(int, struct sockaddr _far *);
int _far SoListen(int);
int _far SoAccept(int, struct sockaddr _far *);
int _far SoReceive(int, struct sockaddr _far *, u_char _far *, u_int);
int _far SoSend(int, struct sockaddr _far *, u_char _far *, u_int);
int _far SoConnect(int, struct sockaddr _far *);
int _far SoRead(int, u_char _far *, u_int);
int _far SoWrite(int, u_char _far *, u_int);
int _far SoClose(int);
void _far SoFree(int);
